package svc

import (
	"applet/app/admin/md"
	svc "applet/app/admin/svc/enterprise_manage"
	md2 "applet/app/customer/md"
	svc2 "applet/app/customer/svc"
	"applet/app/db"
	"applet/app/enum"
	"applet/app/utils"
	"errors"
	"time"
)

func NursingHomeOrderRefundList(req md.NursingHomeOrderRefundListReq) (resp []md.NursingHomeOrderRefundListResp, total int64, err error) {
	var m []*db.NursingHomeUserRefundDayWithData
	sess := db.Db.Where("1=1")
	if req.EnterpriseId != 0 {
		sess.And("enterprise.id =?", req.EnterpriseId)
	}
	if req.Phone != "" {
		sess.And("user.phone like ?", "%"+req.Name+"%")
	}
	if req.Name != "" {
		sess.And("user_identity.name like ?", "%"+req.Phone+"%")
	}
	if req.Kind != 0 {
		sess.And("nursing_home_user_with_day.kind = ?", req.Kind)
	}
	if req.State != 0 {
		sess.And("nursing_home_user_refund_day.state = ?", req.State)
	}
	if req.StartDate != "" {
		sess.And("nursing_home_user_refund_day.create_at >= ?", req.StartDate)
	}
	if req.EndDate != "" {
		sess.And("nursing_home_user_refund_day.create_at <= ?", req.EndDate)
	}
	if req.OutTradeNo != "" {
		sess.And("nursing_home_user_refund_day.out_trade_no like ?", "%"+req.OutTradeNo+"%")
	}
	if req.OutRequestNo != "" {
		sess.And("nursing_home_user_refund_day.out_request_no like ?", "%"+req.OutRequestNo+"%")
	}

	var classWithUserIdentityIdsOne []int
	var classWithUserIdentityIdsTwo []int
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()

	if len(classWithUserIdentityIdsOne) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsOne)
	}
	if len(classWithUserIdentityIdsTwo) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsTwo)
	}

	total, err = sess.
		Join("LEFT", "nursing_home_user_with_day", "nursing_home_user_refund_day.records_id = nursing_home_user_with_day.id").
		Join("LEFT", "nursing_home_package_ord", "nursing_home_user_refund_day.out_trade_no = nursing_home_package_ord.out_trade_no").
		Join("LEFT", "user_identity", "nursing_home_user_with_day.identity_id = user_identity.id").
		Join("LEFT", "user", "user_identity.uid = user.id").
		Join("LEFT", "enterprise", "user_identity.enterprise_id = enterprise.id").
		Desc("nursing_home_user_refund_day.id").
		Limit(req.Limit, (req.Page-1)*req.Limit).FindAndCount(&m)
	if err != nil {
		return nil, 0, err
	}

	for _, v := range m {
		resp = append(resp, md.NursingHomeOrderRefundListResp{
			Id:               v.NursingHomeUserRefundDay.Id,
			OutTradeNo:       v.NursingHomeUserRefundDay.OutTradeNo,
			OutRequestNo:     v.NursingHomeUserRefundDay.OutRequestNo,
			Name:             v.UserIdentity.Name,
			Phone:            v.User.Phone,
			EnterpriseName:   v.Enterprise.Name,
			Kind:             v.NursingHomeUserWithDay.Kind,
			UserIdentityKind: v.UserIdentity.Kind,
			Amount:           v.NursingHomeUserRefundDay.Amount,
			State:            v.NursingHomeUserRefundDay.State,
			CreateAt:         v.NursingHomeUserRefundDay.CreateAt,
			RefundDate:       v.NursingHomeUserRefundDay.RefundDate,
			Memo:             v.NursingHomeUserRefundDay.Memo,
		})
	}
	return
}

func NursingHomeOrderRefundAudit(req md.NursingHomeOrderRefundAuditReq) (err error) {
	sysCfgDb := db.SysCfgDb{}
	sysCfgDb.Set()
	sysCfg := sysCfgDb.SysCfgFindWithDb(enum.JsapiPayAppAutToken, enum.OpenAlipayAppid, enum.OpenAlipayAppPrivateKey, enum.OpenAlipayPublicKey)

	session := db.Db.NewSession()
	defer session.Close()
	session.Begin()

	//限制30条
	if len(req.Ids) > 30 {
		err = errors.New("受理数据过长，请分批次处理")
		_ = session.Rollback()
		return
	}
	NursingHomeUserRefundDayDb := db.NursingHomeUserRefundDayDb{}
	NursingHomeUserRefundDayDb.Set(0)
	NursingHomeUserWithDayDb := db.NursingHomeUserWithDayDb{}
	NursingHomeUserWithDayDb.Set(0)
	for _, v := range req.Ids {
		returnDay, err1 := NursingHomeUserRefundDayDb.GetNursingHomeUserRefundDay(utils.StrToInt(v))
		if err1 != nil {
			_ = session.Rollback()
			return err1
		}
		if returnDay.State != enum.NursingHomeUserRefundDayStateForAuditing {
			_ = session.Rollback()
			return errors.New("请勿重复审核申请单！")
		}
		userWithDay, err3 := NursingHomeUserWithDayDb.GetNursingHomeUserWithDay(returnDay.RecordsId)
		if err3 != nil {
			_ = session.Rollback()
			return err3
		}

		//1、更新状态
		if req.State == 1 {
			returnDay.State = enum.NursingHomeUserRefundDayStateForAuditPass
			userWithDay.State = enum.NursingHomeUserWithDayStateForCancel
			time.Sleep(250 * time.Millisecond) //TODO::避免频繁调用
			//调用支付宝进行退款
			err6, _ := svc2.OldCurlAlipayTradeRefund(md2.OldCurlAlipayTradeRefundReq{
				Config: struct {
					PayAliAppId      string `json:"pay_ali_app_id" label:"支付宝开放平台-第三方应用-appid"`
					PayAliPrivateKey string `json:"pay_ali_private_key" label:"支付宝开放平台-第三方应用-接口加签-应用私钥"`
					PayAliPublicKey  string `json:"pay_ali_public_key" label:"支付宝开放平台-第三方应用-接口加签-支付宝公钥"`
				}{
					PayAliAppId:      sysCfg[enum.OpenAlipayAppid],
					PayAliPrivateKey: sysCfg[enum.OpenAlipayAppPrivateKey],
					PayAliPublicKey:  sysCfg[enum.OpenAlipayPublicKey],
				},
				OutTradeNo:   returnDay.OutTradeNo,
				RefundAmount: returnDay.Amount,
				RefundReason: "央厨订餐退款",
				OutRequestNo: returnDay.OutRequestNo,
				AppAuthToken: sysCfg[enum.JsapiPayAppAutToken],
			})
			if err6 != nil {
				_ = session.Rollback()
				return err6
			}

			returnDay.State = enum.NursingHomeUserRefundDayStateForAuditComplete
			returnDay.RefundDate = time.Now().Format("2006-01-02 15:04:05")
		} else {
			returnDay.State = enum.NursingHomeUserRefundDayStateForAuditReject
			userWithDay.State = enum.NursingHomeUserWithDayStateForWait
		}

		returnDay.Memo = req.Memo
		updateAck, err2 := NursingHomeUserRefundDayDb.NursingHomeUserRefundDayUpdate(returnDay.Id, returnDay, "state", "memo", "refund_date")
		if err2 != nil {
			_ = session.Rollback()
			return err2
		}
		if updateAck <= 0 {
			_ = session.Rollback()
			err = errors.New("更新退款订单记录状态失败")
			return
		}

		updateAck1, err4 := NursingHomeUserWithDayDb.NursingHomeUserWithDayUpdate(userWithDay.Id, userWithDay, "state")
		if err4 != nil {
			_ = session.Rollback()
			return err4
		}
		if updateAck1 <= 0 {
			_ = session.Rollback()
			err = errors.New("更新退款就餐记录状态失败")
			return
		}

		//2、处理订单状态
		err5 := svc.JudgePackageOrdOrdState(returnDay.OutTradeNo, nil)
		if err5 != nil {
			_ = session.Rollback()
			return err5
		}

		if req.State == 1 {

		}
	}

	return session.Commit()
}
