package svc

import (
	"applet/app/admin/lib/auth"
	"applet/app/db"
	"applet/app/db/model"
	"errors"
	"github.com/gin-gonic/gin"
	"strings"
)

func GetUser(c *gin.Context) *model.Admin {
	user, _ := c.Get("admin")
	if user == nil {
		return &model.Admin{
			AdmId:    0,
			Username: "",
			Password: "",
			State:    0,
			CreateAt: "",
			UpdateAt: "",
		}
	}
	return user.(*model.Admin)
}

func CheckUser(c *gin.Context) (*model.Admin, error) {
	token := c.GetHeader("Authorization")
	if token == "" {
		return nil, errors.New("token not exist")
	}
	// 按空格分割
	parts := strings.SplitN(token, " ", 2)
	if !(len(parts) == 2 && parts[0] == "Bearer") {
		return nil, errors.New("token format error")
	}
	// parts[1]是获取到的tokenString，我们使用之前定义好的解析JWT的函数来解析它
	mc, err := auth.ParseToken(parts[1])
	if err != nil {
		return nil, err
	}

	// 获取admin
	adminDb := db.AdminDb{}
	adminDb.Set()
	admin, err := adminDb.GetAdmin(mc.AdmId)
	if err != nil {
		return nil, err
	}
	return admin, nil
}
