package hdl

import (
	"applet/app/customer/lib/validate"
	"applet/app/customer/md"
	"applet/app/customer/svc"
	"applet/app/db"
	"applet/app/db/model"
	"applet/app/e"
	"applet/app/enum"
	svc2 "applet/app/svc"
	"applet/app/utils"
	"applet/app/utils/cache"
	"applet/app/utils/logx"
	"fmt"
	"github.com/gin-gonic/gin"
	"github.com/medivhzhan/weapp/v2"
	"regexp"
	"time"
)

func WxAppletLogin(c *gin.Context) {
	code := c.DefaultQuery("code", "")
	sysCfgDb := db.SysCfgDb{}
	sysCfgDb.Set()
	cfg := sysCfgDb.SysCfgFindWithDb(enum.WxAppletAppId, enum.WxAppletAppSecret)
	req, err := weapp.Login(cfg[enum.WxAppletAppId], cfg[enum.WxAppletAppSecret], code)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	// key是否存在
	cacheKey := md.WxSessionCacheKey
	cacheKeyExist := false
	if cache.Exists(cacheKey) {
		cacheKeyExist = true
	}

	// 设置缓存
	_, err = cache.HSet(cacheKey, req.OpenID, req.SessionKey)
	if err != nil {
		_ = logx.Error(err)
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	if !cacheKeyExist { // 如果是首次设置 设置过期时间
		//_, err := cache.Expire(cacheKey, md.CfgCacheTime)
		//if err != nil {
		//	_ = logx.Error(err)
		//	return ""
		//}
	}

	e.OutSuc(c, md.WxAppletLoginResponse{
		OpenId:  req.OpenID,
		UnionId: req.UnionID,
	}, nil)
	return
}

func WxGetAccessToken(c *gin.Context) {
	accessToken, err := svc.GetWxAccessToken()
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}

	e.OutSuc(c, accessToken, nil)
	return
}

func WxDecryptUserInfo(c *gin.Context) {
	var req md.WxDecryptUserInfoReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	//获取sessionKey
	get, err := cache.HGetString(md.WxSessionCacheKey, req.OpenId)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	if get == "" {
		e.OutErr(c, e.ERR_NO_DATA, "请先完成微信登录流程")
		return
	}

	res, err := weapp.DecryptUserInfo(get, req.RawData, req.EncryptedData, req.Signature, req.IV)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}

	e.OutSuc(c, res, nil)
	return
}

func WxDecryptMobile(c *gin.Context) {
	var req md.WxDecryptMobileReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	//获取sessionKey
	get, err := cache.HGetString(md.WxSessionCacheKey, req.OpenId)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	if get == "" {
		e.OutErr(c, e.ERR_NO_DATA, "请先完成微信登录流程")
		return
	}
	res, err := weapp.DecryptMobile(get, req.EncryptedData, req.IV)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}

	res.PhoneNumber = utils.Base64StdEncode(res.PhoneNumber)

	e.OutSuc(c, res, nil)
	return
}

func Login(c *gin.Context) {
	var req md.LoginReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	userDb := db.UserDb{}
	userDb.Set()
	user, err := userDb.GetUserByPhone(req.Phone)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err)
		return
	}
	if user == nil {
		e.OutErr(c, e.ERR_NO_DATA, "用户信息不存在")
		return
	}
	ip := utils.GetIP(c.Request)
	key := fmt.Sprintf(md.UserJwtTokenKey, ip, utils.AnyToString(user.Id))
	token, err := svc.HandleLoginToken(key, user)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, md.LoginResponse{
		Token: token,
	}, nil)
	return
}

func Register(c *gin.Context) {
	var req md.RegisterReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = svc2.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	//TODO::解密
	phone := utils.Base64StdDecode(req.Phone)
	if phone == "" {
		e.OutErr(c, e.ERR, "非法/恶意 参数!!!")
		return
	}
	req.Phone = phone
	// 编译正则表达式
	pattern := `^1[3456789]\d{9}$`
	r := regexp.MustCompile(pattern)

	// 验证手机号码
	if !r.MatchString(req.Phone) {
		e.OutErr(c, e.ERR, "非法手机号")
		return
	}

	now := time.Now()
	userDb := db.UserDb{}
	userDb.Set()
	user, err := userDb.GetUserByPhone(req.Phone)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err)
		return
	}
	if user == nil {
		user = &model.User{
			UserId:   req.UserId,
			OpenId:   req.OpenId,
			UnionId:  req.UnionId,
			Nickname: req.Nickname,
			Avatar:   req.Avatar,
			Phone:    req.Phone,
			Memo:     "",
			CreateAt: now.Format("2006-01-02 15:04:05"),
			UpdateAt: now.Format("2006-01-02 15:04:05"),
		}
		insertAffected, err1 := userDb.UserInsert(user)
		if err1 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err1)
			return
		}
		if insertAffected <= 0 {
			e.OutErr(c, e.ERR_DB_ORM, "新增用户数据失败")
			return
		}
	} else {
		user.UpdateAt = now.Format("2006-01-02 15:04:05")
		if req.Nickname != "" {
			user.Nickname = req.Nickname
		}
		if req.Avatar != "" {
			user.Avatar = req.Avatar
		}

		if req.UserId != "" {
			//支付宝
			user.UserId = req.UserId
		} else {
			//微信
			user.OpenId = req.OpenId
			user.UnionId = req.UnionId
		}
		updateAffected, err1 := userDb.UpdateUser(user)
		if err1 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err1)
			return
		}
		if updateAffected <= 0 {
			e.OutErr(c, e.ERR_DB_ORM, "更新用户数据失败")
			return
		}
	}

	ip := utils.GetIP(c.Request)
	key := fmt.Sprintf(md.UserJwtTokenKey, ip, utils.AnyToString(user.Id))
	token, err := svc.HandleLoginToken(key, user)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}

	e.OutSuc(c, md.LoginResponse{
		Token: token,
	}, nil)
	return
}

func UpdateUser(c *gin.Context) {
	var req md.RegisterReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = svc2.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	// 编译正则表达式
	pattern := `^1[3456789]\d{9}$`
	r := regexp.MustCompile(pattern)

	// 验证手机号码
	if !r.MatchString(req.Phone) {
		e.OutErr(c, e.ERR, "非法手机号")
		return
	}

	now := time.Now()
	userDb := db.UserDb{}
	userDb.Set()
	user, err := userDb.GetUserByPhone(req.Phone)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err)
		return
	}
	if user == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查詢到相應賬戶記錄！")
		return
	} else {
		user.UpdateAt = now.Format("2006-01-02 15:04:05")
		if req.Nickname != "" {
			user.Nickname = req.Nickname
		}
		if req.Avatar != "" {
			user.Avatar = req.Avatar
		}

		if req.UserId != "" {
			//支付宝
			user.UserId = req.UserId
		} else {
			//微信
			user.OpenId = req.OpenId
			user.UnionId = req.UnionId
		}
		updateAffected, err1 := userDb.UpdateUser(user)
		if err1 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err1)
			return
		}
		if updateAffected <= 0 {
			e.OutErr(c, e.ERR_DB_ORM, "更新用户数据失败")
			return
		}
	}

	e.OutSuc(c, "success", nil)
	return
}
